@@ -16,7 +16,8 @@ MIT
 """
 import json
 import requests
-from IPython.display import display, HTML, Image, Video
+from IPython.display import display, HTML, image
+from IPython.core.display import Video
 
 session = requests.Session()
 url = "https://plotapi.com"
@@ -164,3 +165,10 @@ class Terminus(Visualisation):
         params['links'] = links
         endpoint = "terminus"
         super().__init__(params, endpoint)
+
+class BarFight(Visualisation):
+    def __init__(self, samples, **kwargs):
+        params = kwargs
+        params['samples'] = samples
+        endpoint = "barfight"
+        super().__init__(params, endpoint)
